==> haskell-vector-th-unbox-0.2.1.6-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-4zK7oCb71eH1479ZMEneUA
key: vector-th-unbox-0.2.1.6-4zK7oCb71eH1479ZMEneUA
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: 024a89e69f6c7dc1577b8a2a288f29af
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.4.2/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.4.2/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-4zK7oCb71eH1479ZMEneUA
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=6eab66b6328cb1f1f60a88d42282d4d0
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.1.6-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
key: vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: 1dd1e33bf65274e509e9470910c817b2
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
